@@ -5,7 +5,7 @@
  *
  * pidof.c	Tries to get the pid of the process[es] named.
  *
- * Version:	2.81 31-Jul-2001 MvS
+ * Version:	2.85 14-Apr-2003 MvS
  *
  * Usage:	killall5 [-][signal]
  *		pidof [-s] [-o omitpid [-o omitpid]] program [program..]
@@ -20,7 +20,7 @@
  *		- swapped out programs pids are caught now
  *
  *		This file is part of the sysvinit suite,
- *		Copyright 1991-2001 Miquel van Smoorenburg.
+ *		Copyright 1991-2003 Miquel van Smoorenburg.
  *
  *		This program is free software; you can redistribute it and/or
  *		modify it under the terms of the GNU General Public License
@@ -30,6 +30,7 @@
 #include <sys/types.h>
 #include <stdio.h>
 #include <string.h>
+#include <errno.h>
 #include <stdlib.h>
 #include <unistd.h>
 #include <sys/wait.h>
@@ -40,7 +41,7 @@
 #include <getopt.h>
 #include <stdarg.h>
 
-char *Version = "@(#)killall5 2.81 31-Jul-2001 miquels@cistron.nl";
+char *Version = "@(#)killall5 2.85 14-Apr-2003 miquels@cistron.nl";
 
 /* Info about a process. */
 typedef struct _proc_
@@ -98,7 +99,8 @@ void *xmalloc(int bytes)
 int mount_proc(void)
 {
 	struct stat st;
-	int pid, wst;
+	pid_t pid, rc;
+	int wst;
 	char *args[] = { "mount", "-t", "proc", "none", "/proc", NULL };
 	int did_mount = 0;
 
@@ -121,9 +123,10 @@ int mount_proc(void)
 			exit(1);
 		}
 		/* Wait for child. */
-		while (wait(&wst) != pid)
-			;
-		if (WEXITSTATUS(wst) != 0)
+		while ((rc = wait(&wst)) != pid)
+			if (rc < 0 && errno == ECHILD)
+				break;
+		if (rc != pid || WEXITSTATUS(wst) != 0)
 			nsyslog(LOG_ERR, "mount returned non-zero exit status");
 
 		did_mount = 1;
