@@ -8,7 +8,7 @@
  *		encrypted root password is "x" the shadow
  *		password will be used.
  *
- * Version:	@(#)sulogin 2.81 31-Jul-2001 miquels@cistron.nl
+ * Version:	@(#)sulogin 2.85 14-Apr-2003 miquels@cistron.nl
  *
  */
 
@@ -35,7 +35,7 @@
 #define F_SHADOW	"/etc/shadow"
 #define BINSH		"/bin/sh"
 
-char *Version = "@(#)sulogin 2.81 31-Jul-2001 miquels@cistron.nl";
+char *Version = "@(#)sulogin 2.85 14-Apr-2003 miquels@cistron.nl";
 
 int timeout = 0;
 int profile = 0;
@@ -240,7 +240,7 @@ struct passwd *getrootpwent(int try_manually)
  *	Ask for the password. Note that there is no
  *	default timeout as we normally skip this during boot.
  */
-char *getpasswd(void)
+char *getpasswd(char *crypted)
 {
 	struct sigaction sa;
 	struct termios old, tty;
@@ -248,7 +248,10 @@ char *getpasswd(void)
 	char *ret = pass;
 	int i;
 
-	printf("Give root password for maintenance\n");
+	if (crypted[0])
+		printf("Give root password for maintenance\n");
+	else
+		printf("Press enter for maintenance\n");
 	printf("(or type Control-D for normal startup): ");
 	fflush(stdout);
 
@@ -387,6 +390,7 @@ int main(int argc, char **argv)
 			perror(tty);
 		} else if (!isatty(fd)) {
 			fprintf(stderr, "%s: not a tty\n", tty);
+			close(fd);
 		} else {
 
 			/*
@@ -433,7 +437,7 @@ int main(int argc, char **argv)
 	 *	Ask for the password.
 	 */
 	while(pwd) {
-		if (pwd->pw_passwd[0] && (p = getpasswd()) == NULL) break;
+		if ((p = getpasswd(pwd->pw_passwd)) == NULL) break;
 		if (pwd->pw_passwd[0] == 0 ||
 		    strcmp(crypt(p, pwd->pw_passwd), pwd->pw_passwd) == 0)
 			sushell(pwd);
